==> nucwf-1.0.1.tar.gz: nucwf-1.0.1/examples/createdatabase_a3_fromoutput.py <==
# this script creates from the files in a directory a databased of wave function files
# files are compressed when added, all files of the input directory need to be proper
# wave functions, files are added to the online database 

from nucwf import access
import os
import glob
import re
import fileextract as fe
import re

tolerance=1e-6
uploaddir=os.environ["SCRATCH"]+"/dbupload"
workdir=os.environ["SCRATCH"]+"/wfdbtest/"
inputdir=os.environ["HOME"]+"/papers/srg_evolution_in_4n/data/he3-h3-srg-jube/000065/"


def get_wffile(OUT):
   """Method extracts wave function file name from output"""
   pattern=re.compile(r"WAVEOUT\:\s*(.*)\s*")
   waveout=None
   for line in open(OUT):
     if "WAVEOUT:" in line:  
       regexpr=pattern.search(line)  
       waveout=regexpr.group(1)
       exit
   if waveout==None:
      pattern=re.compile(r"work/(.*).out")
      regexpr=pattern.search(OUT)
      waveout=os.environ["SCRATCH"]+"/3n-wf/"+regexpr.group(1)+".wave.h5"
   return waveout
    


# create database, download one if existent
wfdb=access.database(workdir=workdir)

filelist=glob.glob(inputdir+'0*submit/work/h*out')

for file_in in filelist:
  # get the run number    
  results=fe.getwfprop(file_in)
  # get file name of wave function and read it in
  waveout=get_wffile(file_in)
  print("Read file: ",waveout)
  wavein=access.wavefa3(waveout,printlevel=1)
  # get info from file 
  labels=wavein.get_labels()
  # augment by info from output file 
  labels={**labels,**results}
  # add to database 
  hashnamewf=wfdb.add_file(filename=waveout,**labels)  
  # compress file using the hashname 
  wavein.compress(workdir+hashnamewf,tolerance,printlevel=1)
  # read in again to check basic properties 
  wavein=access.wavefa3(workdir+hashnamewf,printlevel=1)
    
#print complete list of files
print(wfdb.pddf)

# now create upload ready version 
wfdb.prep_upload(uploaddir)

==> nucwf-1.1.0.tar.gz: nucwf-1.1.0/examples/createdatabase_a3_fromoutput.py <==
# this script creates from the files in a directory a databased of wave function files
# files are compressed when added, all files of the input directory need to be proper
# wave functions, files are added to the online database 

from nucwf import access
import os
import glob
import re
import fileextract as fe
import re

tolerance=1e-6
uploaddir=os.environ["SCRATCH"]+"/dbupload"
workdir=os.environ["SCRATCH"]+"/wfdbtest/"
inputdir=os.environ["SCRATCH"]+"/outputs-sfr/"


def get_wffile(OUT):
   """Method extracts wave function file name from output"""
   pattern=re.compile(r"WAVEOUT\:\s*(.*)\s*")
   waveout=None
   for line in open(OUT):
     if "WAVEOUT:  " in line:  
       regexpr=pattern.search(line)  
       waveout=regexpr.group(1)
       exit
   if waveout==None:
      pattern=re.compile(r"work/(.*).out")
      regexpr=pattern.search(OUT)
      waveout=os.environ["SCRATCH"]+"/3n-wf/"+regexpr.group(1)+".wave.h5"
   if "data" in waveout:
      pattern=re.compile(r"data/(.*).wave.h5")
      regexpr=pattern.search(waveout)
      waveout=os.environ["SCRATCH"]+"/3n-wf/"+regexpr.group(1)+".wave.h5"

   return waveout
    


# create database, download one if existent
wfdb=access.database(workdir=workdir)

filelist=glob.glob(inputdir+'*out')

print(filelist)

for file_in in filelist:
  # get the run number    
  results=fe.getwfprop(file_in)
  print(results)
  # get file name of wave function and read it in
  waveout=get_wffile(file_in)
  # 
  print("Read file: ",waveout)
  wavein=access.wavefa3(waveout,printlevel=1)
  # get info from file 
  labels=wavein.get_labels()
  # augment by info from output file 
  labels={**labels,**results}
  # add to database 
  hashnamewf=wfdb.add_file(filename=waveout,**labels)  
  # compress file using the hashname 
  wavein.compress(workdir+hashnamewf,tolerance,printlevel=1)
  # read in again to check basic properties 
  wavein=access.wavefa3(workdir+hashnamewf,printlevel=1)
    
#print complete list of files
print(wfdb.pddf)

# now create upload ready version 
wfdb.prep_upload(uploaddir)
